==> openshift-model-5.4.1-sources.jar: io/fabric8/openshift/api/model/SchedulerSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class SchedulerSpecFluentImpl<A extends io.fabric8.openshift.api.model.SchedulerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.SchedulerSpecFluent<A> {

    private java.lang.String defaultNodeSelector;
    private java.lang.Boolean mastersSchedulable;
    private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder policy;

    public SchedulerSpecFluentImpl() {
    }

    public SchedulerSpecFluentImpl(io.fabric8.openshift.api.model.SchedulerSpec instance) {
        this.withDefaultNodeSelector(instance.getDefaultNodeSelector()); 
        this.withMastersSchedulable(instance.getMastersSchedulable()); 
        this.withPolicy(instance.getPolicy()); 
    }

    public java.lang.String getDefaultNodeSelector() {
        return this.defaultNodeSelector;
    }

    public A withDefaultNodeSelector(java.lang.String defaultNodeSelector) {
        this.defaultNodeSelector=defaultNodeSelector; return (A) this;
    }

    public java.lang.Boolean hasDefaultNodeSelector() {
        return this.defaultNodeSelector != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withDefaultNodeSelector instead.
     */
        public A withNewDefaultNodeSelector(java.lang.String arg0) {
        return (A)withDefaultNodeSelector(new String(arg0));
    }

    public java.lang.Boolean getMastersSchedulable() {
        return this.mastersSchedulable;
    }

    public A withMastersSchedulable(java.lang.Boolean mastersSchedulable) {
        this.mastersSchedulable=mastersSchedulable; return (A) this;
    }

    public java.lang.Boolean hasMastersSchedulable() {
        return this.mastersSchedulable != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildPolicy instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.ConfigMapNameReference getPolicy() {
        return this.policy!=null?this.policy.build():null;
    }

    public io.fabric8.openshift.api.model.ConfigMapNameReference buildPolicy() {
        return this.policy!=null?this.policy.build():null;
    }

    public A withPolicy(io.fabric8.openshift.api.model.ConfigMapNameReference policy) {
        _visitables.get("policy").remove(this.policy);
        if (policy!=null){ this.policy= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(policy); _visitables.get("policy").add(this.policy);} return (A) this;
    }

    public java.lang.Boolean hasPolicy() {
        return this.policy != null;
    }

    public A withNewPolicy(java.lang.String name) {
        return (A)withPolicy(new ConfigMapNameReference(name));
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> withNewPolicy() {
        return new io.fabric8.openshift.api.model.SchedulerSpecFluentImpl.PolicyNestedImpl();
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> withNewPolicyLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
        return new io.fabric8.openshift.api.model.SchedulerSpecFluentImpl.PolicyNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editPolicy() {
        return withNewPolicyLike(getPolicy());
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editOrNewPolicy() {
        return withNewPolicyLike(getPolicy() != null ? getPolicy(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editOrNewPolicyLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
        return withNewPolicyLike(getPolicy() != null ? getPolicy(): item);
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SchedulerSpecFluentImpl that = (SchedulerSpecFluentImpl) o;
        if (defaultNodeSelector != null ? !defaultNodeSelector.equals(that.defaultNodeSelector) :that.defaultNodeSelector != null) return false;
        if (mastersSchedulable != null ? !mastersSchedulable.equals(that.mastersSchedulable) :that.mastersSchedulable != null) return false;
        if (policy != null ? !policy.equals(that.policy) :that.policy != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(defaultNodeSelector,  mastersSchedulable,  policy,  super.hashCode());
    }

    public class PolicyNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<N>> implements io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;

            PolicyNestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
                this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
                        
            }

            PolicyNestedImpl() {
                this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) SchedulerSpecFluentImpl.this.withPolicy(builder.build());
            }

            public N endPolicy() {
                return and();
            }
    }


}

==> openshift-model-5.7.1-sources.jar: io/fabric8/openshift/api/model/SchedulerSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class SchedulerSpecFluentImpl<A extends io.fabric8.openshift.api.model.SchedulerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.SchedulerSpecFluent<A> {

    private java.lang.String defaultNodeSelector;
    private java.lang.Boolean mastersSchedulable;
    private io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder policy;
    private java.lang.String profile;

    public SchedulerSpecFluentImpl() {
    }

    public SchedulerSpecFluentImpl(io.fabric8.openshift.api.model.SchedulerSpec instance) {
        this.withDefaultNodeSelector(instance.getDefaultNodeSelector()); 
        this.withMastersSchedulable(instance.getMastersSchedulable()); 
        this.withPolicy(instance.getPolicy()); 
        this.withProfile(instance.getProfile()); 
    }

    public java.lang.String getDefaultNodeSelector() {
        return this.defaultNodeSelector;
    }

    public A withDefaultNodeSelector(java.lang.String defaultNodeSelector) {
        this.defaultNodeSelector=defaultNodeSelector; return (A) this;
    }

    public java.lang.Boolean hasDefaultNodeSelector() {
        return this.defaultNodeSelector != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withDefaultNodeSelector instead.
     */
        public A withNewDefaultNodeSelector(java.lang.String arg0) {
        return (A)withDefaultNodeSelector(new String(arg0));
    }

    public java.lang.Boolean getMastersSchedulable() {
        return this.mastersSchedulable;
    }

    public A withMastersSchedulable(java.lang.Boolean mastersSchedulable) {
        this.mastersSchedulable=mastersSchedulable; return (A) this;
    }

    public java.lang.Boolean hasMastersSchedulable() {
        return this.mastersSchedulable != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildPolicy instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.ConfigMapNameReference getPolicy() {
        return this.policy!=null?this.policy.build():null;
    }

    public io.fabric8.openshift.api.model.ConfigMapNameReference buildPolicy() {
        return this.policy!=null?this.policy.build():null;
    }

    public A withPolicy(io.fabric8.openshift.api.model.ConfigMapNameReference policy) {
        _visitables.get("policy").remove(this.policy);
        if (policy!=null){ this.policy= new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(policy); _visitables.get("policy").add(this.policy);} return (A) this;
    }

    public java.lang.Boolean hasPolicy() {
        return this.policy != null;
    }

    public A withNewPolicy(java.lang.String name) {
        return (A)withPolicy(new ConfigMapNameReference(name));
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> withNewPolicy() {
        return new io.fabric8.openshift.api.model.SchedulerSpecFluentImpl.PolicyNestedImpl();
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> withNewPolicyLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
        return new io.fabric8.openshift.api.model.SchedulerSpecFluentImpl.PolicyNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editPolicy() {
        return withNewPolicyLike(getPolicy());
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editOrNewPolicy() {
        return withNewPolicyLike(getPolicy() != null ? getPolicy(): new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder().build());
    }

    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editOrNewPolicyLike(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
        return withNewPolicyLike(getPolicy() != null ? getPolicy(): item);
    }

    public java.lang.String getProfile() {
        return this.profile;
    }

    public A withProfile(java.lang.String profile) {
        this.profile=profile; return (A) this;
    }

    public java.lang.Boolean hasProfile() {
        return this.profile != null;
    }

    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withProfile instead.
     */
        public A withNewProfile(java.lang.String arg0) {
        return (A)withProfile(new String(arg0));
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SchedulerSpecFluentImpl that = (SchedulerSpecFluentImpl) o;
        if (defaultNodeSelector != null ? !defaultNodeSelector.equals(that.defaultNodeSelector) :that.defaultNodeSelector != null) return false;
        if (mastersSchedulable != null ? !mastersSchedulable.equals(that.mastersSchedulable) :that.mastersSchedulable != null) return false;
        if (policy != null ? !policy.equals(that.policy) :that.policy != null) return false;
        if (profile != null ? !profile.equals(that.profile) :that.profile != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(defaultNodeSelector,  mastersSchedulable,  policy,  profile,  super.hashCode());
    }

    public class PolicyNestedImpl<N> extends io.fabric8.openshift.api.model.ConfigMapNameReferenceFluentImpl<io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<N>> implements io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder builder;

            PolicyNestedImpl(io.fabric8.openshift.api.model.ConfigMapNameReference item) {
                this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this, item);
                        
            }

            PolicyNestedImpl() {
                this.builder = new io.fabric8.openshift.api.model.ConfigMapNameReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) SchedulerSpecFluentImpl.this.withPolicy(builder.build());
            }

            public N endPolicy() {
                return and();
            }
    }


}
